@@ -1,6 +1,6 @@
 #!/bin/sh
 
-find . -type f -name '*.svg' -exec xmllint --noout {} + 2> xmlerrors
+find "${1:-.}" -type f -name '*.svg' -exec xmllint --noout {} + 2> xmlerrors
 if [ -s xmlerrors ]; then
     cat xmlerrors
     rm xmlerrors
